/* Sketch for the Automatic Motor Reversal Project
*/
//Identify pins that will not change
const int ledPin1 = 12; //LED1 in schematic
const int ledPin2 = 13; //LED2 in schematic
const int analog0 = A0;
const int analog1 = A1;
int analogValue0 = 0; //Identify variables for analog inputs
int analogValue1 = 0;
int analogdifference = 0;
int threshold = 100; //The threshold value calculated to stop the motor
int reading;
int state;
int previous = LOW;
int count = 0;
int numberstops = 250;
int time = 0; //The last time the motor reversed
//Amount of time to wait to get rid of the jitters when the motor reverses
int debounce = 400;
void setup() { //This is the setup routine
  //Initializes pins as input or output
  pinMode(analog0, INPUT);
  pinMode(analog1, INPUT);
  pinMode(ledPin1, OUTPUT);
  pinMode(ledPin2, OUTPUT);
  Serial.begin(9600); //Was used in setting up the parameters
}
void loop() { //This begins the processing section
  //Enter an endless do-nothing loop after the counter reaches the limit
  while (count > numberstops) {
    digitalWrite(ledPin1, LOW);
    digitalWrite(ledPin2, LOW);
  }
  analogValue0 = (analogRead(analog0)); //Read the analog values
  analogValue1 = (analogRead(analog1));
  //Setting up the analog difference
  analogdifference = analogValue1 - analogValue0; //This is the voltage drop
  //analogValue1 will be greater than analogValue0
  //These were added to view what was happening on the serial monitor
  Serial.print("count = ");
  Serial.println(count);
  Serial.print("analogdifference = ");
  Serial.println(analogdifference);
  Serial.println();
  Serial.print("numberstops = ");
  Serial.println(numberstops);
  //This comparator looks at the difference or drop across the resistor
  if (analogdifference > threshold) {
    reading = HIGH;
  }
  else {
    reading = LOW;
  }
  //Toggles the output and includes the debounce
  if (reading == HIGH && previous == LOW && millis() - time > debounce) {
    if (state == HIGH) {
      state = LOW;
    }
    else {
      state = HIGH;
    }
    //Increments the counter each time the motor reverses
    count++;
    time = millis();
  }
  //Writes the state to the output pins that drive the H-Bridge
  digitalWrite(ledPin1, state);
  digitalWrite(ledPin2, !state);
  previous = reading;
}
